kedro.extras.datasets.biosequence.BioSequenceDataSet — Kedro 0.17.6 documentation

# kedro.extras.datasets.biosequence.BioSequenceDataSet

class `kedro.extras.datasets.biosequence.` `BioSequenceDataSet`(filepath, load_args=None, save_args=None, credentials=None, fs_args=None)

  `BioSequenceDataSet` loads and saves data to a sequence file.

  Example:

      from kedro.extras.datasets.biosequence import BioSequenceDataSet
      from io import StringIO
      from Bio import SeqIO

      data = ">Alpha\nACCGGATGTA\n>Beta\nAGGCTCGGTTA\n"
      raw_data = []
      for record in SeqIO.parse(StringIO(data), "fasta"):
          raw_data.append(record)

      data_set = BioSequenceDataSet(filepath="ls_orchid.fasta",
                                    load_args={"format": "fasta"},
                                    save_args={"format": "fasta"})
      data_set.save(raw_data)
      sequence_list = data_set.load()

      assert raw_data[0].id == sequence_list[0].id
      assert raw_data[0].seq == sequence_list[0].seq

  Attributes

  `DEFAULT_LOAD_ARGS` |
  `DEFAULT_SAVE_ARGS` |

  Methods

  `exists`() | Checks whether a data set’s output already exists by calling the provided _exists() method.
  `from_config`(name, config[, load_version, …]) | Create a data set instance using the configuration provided.
  `invalidate_cache`() | Invalidate underlying filesystem caches.
  `load`() | Loads data by delegation to the provided load method.
  `release`() | Release any cached data.
  `save`(data) | Saves data by delegation to the provided save method.

  `DEFAULT_LOAD_ARGS`: Dict[str, Any] = {}
  `DEFAULT_SAVE_ARGS`: Dict[str, Any] = {}
  `__init__`(filepath, load_args=None, save_args=None, credentials=None, fs_args=None)

    Creates a new instance of `BioSequenceDataSet` pointing to a concrete filepath.

    Parameters

      - filepath (`str`) – Filepath in POSIX format to sequence file prefixed with a protocol like s3://. If prefix is not provided, file protocol (local filesystem) will be used. The prefix should be any protocol supported by `fsspec`.

      - load_args (`Optional`[`Dict`[`str`, `Any`]]) – Options for parsing sequence files by Biopython `SeqIO.parse()`.

      - save_args (`Optional`[`Dict`[`str`, `Any`]]) – file format supported by Biopython `SeqIO.write()`. E.g. {“format”: “fasta”}.

      - credentials (`Optional`[`Dict`[`str`, `Any`]]) – Credentials required to get access to the underlying filesystem. E.g. for `GCSFileSystem` it should look like {“token”: None}.

      - fs_args (`Optional`[`Dict`[`str`, `Any`]]) – Extra arguments to pass into underlying filesystem class constructor (e.g. {“project”: “my-project”} for `GCSFileSystem`), as well as to pass to the filesystem’s open method through nested keys open_args_load and open_args_save. Here you can find all available arguments for open: https://filesystem-spec.readthedocs.io/en/latest/api.html#fsspec.spec.AbstractFileSystem.open All defaults are preserved, except mode, which is set to r when loading and to w when saving.

    Note: Here you can find all supported file formats: https://biopython.org/wiki/SeqIO

  `exists`()

    Checks whether a data set’s output already exists by calling the provided _exists() method.

    Return type

      `bool`

    Returns

      Flag indicating whether the output already exists.

    Raises

      DataSetError – when underlying exists method raises error.

  classmethod `from_config`(name, config, load_version=None, save_version=None)

    Create a data set instance using the configuration provided.

    Parameters

      - name (`str`) – Data set name.

      - config (`Dict`[`str`, `Any`]) – Data set config dictionary.

      - load_version (`Optional`[`str`]) – Version string to be used for `load` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

      - save_version (`Optional`[`str`]) – Version string to be used for `save` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

    Return type

      `AbstractDataSet`

    Returns

      An instance of an `AbstractDataSet` subclass.

    Raises

      DataSetError – When the function fails to create the data set from its config.

  `invalidate_cache`()

    Invalidate underlying filesystem caches.

    Return type

      `None`

  `load`()

    Loads data by delegation to the provided load method.

    Return type

      `Any`

    Returns

      Data returned by the provided load method.

    Raises

      DataSetError – When underlying load method raises error.

  `release`()

    Release any cached data.

    Raises

      DataSetError – when underlying release method raises error.

    Return type

      `None`

  `save`(data)

    Saves data by delegation to the provided save method.

    Parameters

      data (`Any`) – the value to be saved by provided save method.

    Raises

      - DataSetError – when underlying save method raises error.

      - FileNotFoundError – when save method got file instead of dir, on Windows.

      - NotADirectoryError – when save method got file instead of dir, on Unix.

    Return type

      `None`